Class: SplititWebApiV4::ApiErrorResponseException
- Inherits:
-
APIException
- Object
- CoreLibrary::ApiException
- APIException
- SplititWebApiV4::ApiErrorResponseException
- Defined in:
- lib/splitit_web_api_v4/exceptions/api_error_response_exception.rb
Overview
ApiErrorResponse class.
Instance Attribute Summary collapse
-
#error ⇒ ApiErrorModel
TODO: Write general description for this method.
-
#trace_id ⇒ String
TODO: Write general description for this method.
Instance Method Summary collapse
-
#initialize(reason, response) ⇒ ApiErrorResponseException
constructor
The constructor.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
-
#unbox(hash) ⇒ Object
Populates this object by extracting properties from a hash.
Constructor Details
#initialize(reason, response) ⇒ ApiErrorResponseException
The constructor.
23 24 25 26 27 |
# File 'lib/splitit_web_api_v4/exceptions/api_error_response_exception.rb', line 23 def initialize(reason, response) super(reason, response) hash = APIHelper.json_deserialize(@response.raw_body) unbox(hash) end |
Instance Attribute Details
#error ⇒ ApiErrorModel
TODO: Write general description for this method
18 19 20 |
# File 'lib/splitit_web_api_v4/exceptions/api_error_response_exception.rb', line 18 def error @error end |
#trace_id ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/splitit_web_api_v4/exceptions/api_error_response_exception.rb', line 14 def trace_id @trace_id end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
46 47 48 49 |
# File 'lib/splitit_web_api_v4/exceptions/api_error_response_exception.rb', line 46 def inspect class_name = self.class.name.split('::').last "<#{class_name} trace_id: #{@trace_id.inspect}, error: #{@error.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
40 41 42 43 |
# File 'lib/splitit_web_api_v4/exceptions/api_error_response_exception.rb', line 40 def to_s class_name = self.class.name.split('::').last "<#{class_name} trace_id: #{@trace_id}, error: #{@error}>" end |
#unbox(hash) ⇒ Object
Populates this object by extracting properties from a hash. response body.
32 33 34 35 36 37 |
# File 'lib/splitit_web_api_v4/exceptions/api_error_response_exception.rb', line 32 def unbox(hash) return nil unless hash @trace_id = hash.key?('TraceId') ? hash['TraceId'] : SKIP @error = ApiErrorModel.from_hash(hash['Error']) if hash['Error'] end |