Class: SplititWebApiV4::CardValidityResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- SplititWebApiV4::CardValidityResponse
- Defined in:
- lib/splitit_web_api_v4/models/card_validity_response.rb
Overview
CardValidityResponse Model.
Instance Attribute Summary collapse
-
#result ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#validation_errors ⇒ Array[ValidationError]
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(result:, validation_errors: SKIP, additional_properties: nil) ⇒ CardValidityResponse
constructor
A new instance of CardValidityResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(result:, validation_errors: SKIP, additional_properties: nil) ⇒ CardValidityResponse
Returns a new instance of CardValidityResponse.
40 41 42 43 44 45 46 47 |
# File 'lib/splitit_web_api_v4/models/card_validity_response.rb', line 40 def initialize(result:, validation_errors: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @result = result @validation_errors = validation_errors unless validation_errors == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#result ⇒ TrueClass | FalseClass
TODO: Write general description for this method
14 15 16 |
# File 'lib/splitit_web_api_v4/models/card_validity_response.rb', line 14 def result @result end |
#validation_errors ⇒ Array[ValidationError]
TODO: Write general description for this method
18 19 20 |
# File 'lib/splitit_web_api_v4/models/card_validity_response.rb', line 18 def validation_errors @validation_errors end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/splitit_web_api_v4/models/card_validity_response.rb', line 50 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. result = hash.key?('Result') ? hash['Result'] : nil # Parameter is an array, so we need to iterate through it validation_errors = nil unless hash['ValidationErrors'].nil? validation_errors = [] hash['ValidationErrors'].each do |structure| validation_errors << (ValidationError.from_hash(structure) if structure) end end validation_errors = SKIP unless hash.key?('ValidationErrors') # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. CardValidityResponse.new(result: result, validation_errors: validation_errors, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/splitit_web_api_v4/models/card_validity_response.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['result'] = 'Result' @_hash['validation_errors'] = 'ValidationErrors' @_hash end |
.nullables ⇒ Object
An array for nullable fields
36 37 38 |
# File 'lib/splitit_web_api_v4/models/card_validity_response.rb', line 36 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 |
# File 'lib/splitit_web_api_v4/models/card_validity_response.rb', line 29 def self.optionals %w[ validation_errors ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
87 88 89 90 91 |
# File 'lib/splitit_web_api_v4/models/card_validity_response.rb', line 87 def inspect class_name = self.class.name.split('::').last "<#{class_name} result: #{@result.inspect}, validation_errors:"\ " #{@validation_errors.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
80 81 82 83 84 |
# File 'lib/splitit_web_api_v4/models/card_validity_response.rb', line 80 def to_s class_name = self.class.name.split('::').last "<#{class_name} result: #{@result}, validation_errors: #{@validation_errors},"\ " additional_properties: #{@additional_properties}>" end |