Class: SplititWebApiV4::CheckoutUrlData

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/splitit_web_api_v4/models/checkout_url_data.rb

Overview

CheckoutUrlData Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(url: SKIP, valid_until: SKIP, additional_properties: nil) ⇒ CheckoutUrlData

Returns a new instance of CheckoutUrlData.



42
43
44
45
46
47
48
49
# File 'lib/splitit_web_api_v4/models/checkout_url_data.rb', line 42

def initialize(url: SKIP, valid_until: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @url = url unless url == SKIP
  @valid_until = valid_until unless valid_until == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#urlString

TODO: Write general description for this method

Returns:

  • (String)


15
16
17
# File 'lib/splitit_web_api_v4/models/checkout_url_data.rb', line 15

def url
  @url
end

#valid_untilDateTime

TODO: Write general description for this method

Returns:

  • (DateTime)


19
20
21
# File 'lib/splitit_web_api_v4/models/checkout_url_data.rb', line 19

def valid_until
  @valid_until
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/splitit_web_api_v4/models/checkout_url_data.rb', line 52

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  url = hash.key?('Url') ? hash['Url'] : SKIP
  valid_until = if hash.key?('ValidUntil')
                  (DateTimeHelper.from_rfc3339(hash['ValidUntil']) if hash['ValidUntil'])
                else
                  SKIP
                end

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  CheckoutUrlData.new(url: url,
                      valid_until: valid_until,
                      additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



22
23
24
25
26
27
# File 'lib/splitit_web_api_v4/models/checkout_url_data.rb', line 22

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['url'] = 'Url'
  @_hash['valid_until'] = 'ValidUntil'
  @_hash
end

.nullablesObject

An array for nullable fields



38
39
40
# File 'lib/splitit_web_api_v4/models/checkout_url_data.rb', line 38

def self.nullables
  []
end

.optionalsObject

An array for optional fields



30
31
32
33
34
35
# File 'lib/splitit_web_api_v4/models/checkout_url_data.rb', line 30

def self.optionals
  %w[
    url
    valid_until
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



88
89
90
91
92
# File 'lib/splitit_web_api_v4/models/checkout_url_data.rb', line 88

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} url: #{@url.inspect}, valid_until: #{@valid_until.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_custom_valid_untilObject



76
77
78
# File 'lib/splitit_web_api_v4/models/checkout_url_data.rb', line 76

def to_custom_valid_until
  DateTimeHelper.to_rfc3339(valid_until)
end

#to_sObject

Provides a human-readable string representation of the object.



81
82
83
84
85
# File 'lib/splitit_web_api_v4/models/checkout_url_data.rb', line 81

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} url: #{@url}, valid_until: #{@valid_until}, additional_properties:"\
  " #{@additional_properties}>"
end