Class: SplititWebApiV4::ContentSegment

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/splitit_web_api_v4/models/content_segment.rb

Overview

ContentSegment Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(type: SKIP, value: SKIP, label: SKIP, url: SKIP, additional_properties: nil) ⇒ ContentSegment

Returns a new instance of ContentSegment.



53
54
55
56
57
58
59
60
61
62
63
# File 'lib/splitit_web_api_v4/models/content_segment.rb', line 53

def initialize(type: SKIP, value: SKIP, label: SKIP, url: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @type = type unless type == SKIP
  @value = value unless value == SKIP
  @label = label unless label == SKIP
  @url = url unless url == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#labelString

TODO: Write general description for this method

Returns:

  • (String)


22
23
24
# File 'lib/splitit_web_api_v4/models/content_segment.rb', line 22

def label
  @label
end

#typeString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/splitit_web_api_v4/models/content_segment.rb', line 14

def type
  @type
end

#urlString

TODO: Write general description for this method

Returns:

  • (String)


26
27
28
# File 'lib/splitit_web_api_v4/models/content_segment.rb', line 26

def url
  @url
end

#valueString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/splitit_web_api_v4/models/content_segment.rb', line 18

def value
  @value
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/splitit_web_api_v4/models/content_segment.rb', line 66

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  type = hash.key?('Type') ? hash['Type'] : SKIP
  value = hash.key?('Value') ? hash['Value'] : SKIP
  label = hash.key?('Label') ? hash['Label'] : SKIP
  url = hash.key?('Url') ? hash['Url'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ContentSegment.new(type: type,
                     value: value,
                     label: label,
                     url: url,
                     additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



29
30
31
32
33
34
35
36
# File 'lib/splitit_web_api_v4/models/content_segment.rb', line 29

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['type'] = 'Type'
  @_hash['value'] = 'Value'
  @_hash['label'] = 'Label'
  @_hash['url'] = 'Url'
  @_hash
end

.nullablesObject

An array for nullable fields



49
50
51
# File 'lib/splitit_web_api_v4/models/content_segment.rb', line 49

def self.nullables
  []
end

.optionalsObject

An array for optional fields



39
40
41
42
43
44
45
46
# File 'lib/splitit_web_api_v4/models/content_segment.rb', line 39

def self.optionals
  %w[
    type
    value
    label
    url
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



98
99
100
101
102
# File 'lib/splitit_web_api_v4/models/content_segment.rb', line 98

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} type: #{@type.inspect}, value: #{@value.inspect}, label: #{@label.inspect},"\
  " url: #{@url.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



91
92
93
94
95
# File 'lib/splitit_web_api_v4/models/content_segment.rb', line 91

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} type: #{@type}, value: #{@value}, label: #{@label}, url: #{@url},"\
  " additional_properties: #{@additional_properties}>"
end