Class: SplititWebApiV4::InlineContent

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/splitit_web_api_v4/models/inline_content.rb

Overview

InlineContent Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(segments: SKIP, additional_properties: nil) ⇒ InlineContent

Returns a new instance of InlineContent.



35
36
37
38
39
40
41
# File 'lib/splitit_web_api_v4/models/inline_content.rb', line 35

def initialize(segments: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @segments = segments unless segments == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#segmentsArray[ContentSegment]

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/splitit_web_api_v4/models/inline_content.rb', line 14

def segments
  @segments
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/splitit_web_api_v4/models/inline_content.rb', line 44

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  segments = nil
  unless hash['Segments'].nil?
    segments = []
    hash['Segments'].each do |structure|
      segments << (ContentSegment.from_hash(structure) if structure)
    end
  end

  segments = SKIP unless hash.key?('Segments')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  InlineContent.new(segments: segments,
                    additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



17
18
19
20
21
# File 'lib/splitit_web_api_v4/models/inline_content.rb', line 17

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['segments'] = 'Segments'
  @_hash
end

.nullablesObject

An array for nullable fields



31
32
33
# File 'lib/splitit_web_api_v4/models/inline_content.rb', line 31

def self.nullables
  []
end

.optionalsObject

An array for optional fields



24
25
26
27
28
# File 'lib/splitit_web_api_v4/models/inline_content.rb', line 24

def self.optionals
  %w[
    segments
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



78
79
80
81
82
# File 'lib/splitit_web_api_v4/models/inline_content.rb', line 78

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} segments: #{@segments.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



72
73
74
75
# File 'lib/splitit_web_api_v4/models/inline_content.rb', line 72

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} segments: #{@segments}, additional_properties: #{@additional_properties}>"
end