Class: SplititWebApiV4::InstallmentPlanSearchRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- SplititWebApiV4::InstallmentPlanSearchRequest
- Defined in:
- lib/splitit_web_api_v4/models/installment_plan_search_request.rb
Overview
InstallmentPlanSearchRequest Model.
Instance Attribute Summary collapse
-
#installment_plan_numbers ⇒ Array[String]
TODO: Write general description for this method.
-
#merchant_order_reference_ids ⇒ Array[String]
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(installment_plan_numbers: SKIP, merchant_order_reference_ids: SKIP, additional_properties: nil) ⇒ InstallmentPlanSearchRequest
constructor
A new instance of InstallmentPlanSearchRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(installment_plan_numbers: SKIP, merchant_order_reference_ids: SKIP, additional_properties: nil) ⇒ InstallmentPlanSearchRequest
Returns a new instance of InstallmentPlanSearchRequest.
41 42 43 44 45 46 47 48 49 50 51 52 53 |
# File 'lib/splitit_web_api_v4/models/installment_plan_search_request.rb', line 41 def initialize(installment_plan_numbers: SKIP, merchant_order_reference_ids: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @installment_plan_numbers = installment_plan_numbers unless installment_plan_numbers == SKIP unless merchant_order_reference_ids == SKIP @merchant_order_reference_ids = merchant_order_reference_ids end @additional_properties = additional_properties end |
Instance Attribute Details
#installment_plan_numbers ⇒ Array[String]
TODO: Write general description for this method
14 15 16 |
# File 'lib/splitit_web_api_v4/models/installment_plan_search_request.rb', line 14 def installment_plan_numbers @installment_plan_numbers end |
#merchant_order_reference_ids ⇒ Array[String]
TODO: Write general description for this method
18 19 20 |
# File 'lib/splitit_web_api_v4/models/installment_plan_search_request.rb', line 18 def merchant_order_reference_ids @merchant_order_reference_ids end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/splitit_web_api_v4/models/installment_plan_search_request.rb', line 56 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. installment_plan_numbers = hash.key?('InstallmentPlanNumbers') ? hash['InstallmentPlanNumbers'] : SKIP merchant_order_reference_ids = hash.key?('MerchantOrderReferenceIds') ? hash['MerchantOrderReferenceIds'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. InstallmentPlanSearchRequest.new(installment_plan_numbers: installment_plan_numbers, merchant_order_reference_ids: merchant_order_reference_ids, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/splitit_web_api_v4/models/installment_plan_search_request.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['installment_plan_numbers'] = 'InstallmentPlanNumbers' @_hash['merchant_order_reference_ids'] = 'MerchantOrderReferenceIds' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/splitit_web_api_v4/models/installment_plan_search_request.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/splitit_web_api_v4/models/installment_plan_search_request.rb', line 29 def self.optionals %w[ installment_plan_numbers merchant_order_reference_ids ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
87 88 89 90 91 92 |
# File 'lib/splitit_web_api_v4/models/installment_plan_search_request.rb', line 87 def inspect class_name = self.class.name.split('::').last "<#{class_name} installment_plan_numbers: #{@installment_plan_numbers.inspect},"\ " merchant_order_reference_ids: #{@merchant_order_reference_ids.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
79 80 81 82 83 84 |
# File 'lib/splitit_web_api_v4/models/installment_plan_search_request.rb', line 79 def to_s class_name = self.class.name.split('::').last "<#{class_name} installment_plan_numbers: #{@installment_plan_numbers},"\ " merchant_order_reference_ids: #{@merchant_order_reference_ids}, additional_properties:"\ " #{@additional_properties}>" end |