Class: SplititWebApiV4::MaskedCardDetails

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/splitit_web_api_v4/models/masked_card_details.rb

Overview

MaskedCardDetails Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(last4_digits: SKIP, bin: SKIP, issuer_name: SKIP, additional_properties: nil) ⇒ MaskedCardDetails

Returns a new instance of MaskedCardDetails.



47
48
49
50
51
52
53
54
55
56
# File 'lib/splitit_web_api_v4/models/masked_card_details.rb', line 47

def initialize(last4_digits: SKIP, bin: SKIP, issuer_name: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @last4_digits = last4_digits unless last4_digits == SKIP
  @bin = bin unless bin == SKIP
  @issuer_name = issuer_name unless issuer_name == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#binString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/splitit_web_api_v4/models/masked_card_details.rb', line 18

def bin
  @bin
end

#issuer_nameString

TODO: Write general description for this method

Returns:

  • (String)


22
23
24
# File 'lib/splitit_web_api_v4/models/masked_card_details.rb', line 22

def issuer_name
  @issuer_name
end

#last4_digitsString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/splitit_web_api_v4/models/masked_card_details.rb', line 14

def last4_digits
  @last4_digits
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/splitit_web_api_v4/models/masked_card_details.rb', line 59

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  last4_digits = hash.key?('Last4Digits') ? hash['Last4Digits'] : SKIP
  bin = hash.key?('BIN') ? hash['BIN'] : SKIP
  issuer_name = hash.key?('IssuerName') ? hash['IssuerName'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  MaskedCardDetails.new(last4_digits: last4_digits,
                        bin: bin,
                        issuer_name: issuer_name,
                        additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/splitit_web_api_v4/models/masked_card_details.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['last4_digits'] = 'Last4Digits'
  @_hash['bin'] = 'BIN'
  @_hash['issuer_name'] = 'IssuerName'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/splitit_web_api_v4/models/masked_card_details.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/splitit_web_api_v4/models/masked_card_details.rb', line 34

def self.optionals
  %w[
    last4_digits
    bin
    issuer_name
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



89
90
91
92
93
# File 'lib/splitit_web_api_v4/models/masked_card_details.rb', line 89

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} last4_digits: #{@last4_digits.inspect}, bin: #{@bin.inspect}, issuer_name:"\
  " #{@issuer_name.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



82
83
84
85
86
# File 'lib/splitit_web_api_v4/models/masked_card_details.rb', line 82

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} last4_digits: #{@last4_digits}, bin: #{@bin}, issuer_name: #{@issuer_name},"\
  " additional_properties: #{@additional_properties}>"
end