Class: SplititWebApiV4::OffersCardDetails

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/splitit_web_api_v4/models/offers_card_details.rb

Overview

OffersCardDetails Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(card_number:, exp_month:, exp_year:, first_name: SKIP, last_name: SKIP, cvv: SKIP, additional_properties: nil) ⇒ OffersCardDetails

Returns a new instance of OffersCardDetails.



62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/splitit_web_api_v4/models/offers_card_details.rb', line 62

def initialize(card_number:, exp_month:, exp_year:, first_name: SKIP,
               last_name: SKIP, cvv: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @first_name = first_name unless first_name == SKIP
  @last_name = last_name unless last_name == SKIP
  @card_number = card_number
  @exp_month = exp_month
  @exp_year = exp_year
  @cvv = cvv unless cvv == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#card_numberString

TODO: Write general description for this method

Returns:

  • (String)


22
23
24
# File 'lib/splitit_web_api_v4/models/offers_card_details.rb', line 22

def card_number
  @card_number
end

#cvvString

TODO: Write general description for this method

Returns:

  • (String)


34
35
36
# File 'lib/splitit_web_api_v4/models/offers_card_details.rb', line 34

def cvv
  @cvv
end

#exp_monthInteger

TODO: Write general description for this method

Returns:

  • (Integer)


26
27
28
# File 'lib/splitit_web_api_v4/models/offers_card_details.rb', line 26

def exp_month
  @exp_month
end

#exp_yearInteger

TODO: Write general description for this method

Returns:

  • (Integer)


30
31
32
# File 'lib/splitit_web_api_v4/models/offers_card_details.rb', line 30

def exp_year
  @exp_year
end

#first_nameString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/splitit_web_api_v4/models/offers_card_details.rb', line 14

def first_name
  @first_name
end

#last_nameString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/splitit_web_api_v4/models/offers_card_details.rb', line 18

def last_name
  @last_name
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
# File 'lib/splitit_web_api_v4/models/offers_card_details.rb', line 77

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  card_number = hash.key?('CardNumber') ? hash['CardNumber'] : nil
  exp_month = hash.key?('ExpMonth') ? hash['ExpMonth'] : nil
  exp_year = hash.key?('ExpYear') ? hash['ExpYear'] : nil
  first_name = hash.key?('FirstName') ? hash['FirstName'] : SKIP
  last_name = hash.key?('LastName') ? hash['LastName'] : SKIP
  cvv = hash.key?('Cvv') ? hash['Cvv'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  OffersCardDetails.new(card_number: card_number,
                        exp_month: exp_month,
                        exp_year: exp_year,
                        first_name: first_name,
                        last_name: last_name,
                        cvv: cvv,
                        additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



37
38
39
40
41
42
43
44
45
46
# File 'lib/splitit_web_api_v4/models/offers_card_details.rb', line 37

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['first_name'] = 'FirstName'
  @_hash['last_name'] = 'LastName'
  @_hash['card_number'] = 'CardNumber'
  @_hash['exp_month'] = 'ExpMonth'
  @_hash['exp_year'] = 'ExpYear'
  @_hash['cvv'] = 'Cvv'
  @_hash
end

.nullablesObject

An array for nullable fields



58
59
60
# File 'lib/splitit_web_api_v4/models/offers_card_details.rb', line 58

def self.nullables
  []
end

.optionalsObject

An array for optional fields



49
50
51
52
53
54
55
# File 'lib/splitit_web_api_v4/models/offers_card_details.rb', line 49

def self.optionals
  %w[
    first_name
    last_name
    cvv
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



114
115
116
117
118
119
120
# File 'lib/splitit_web_api_v4/models/offers_card_details.rb', line 114

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} first_name: #{@first_name.inspect}, last_name: #{@last_name.inspect},"\
  " card_number: #{@card_number.inspect}, exp_month: #{@exp_month.inspect}, exp_year:"\
  " #{@exp_year.inspect}, cvv: #{@cvv.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



106
107
108
109
110
111
# File 'lib/splitit_web_api_v4/models/offers_card_details.rb', line 106

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} first_name: #{@first_name}, last_name: #{@last_name}, card_number:"\
  " #{@card_number}, exp_month: #{@exp_month}, exp_year: #{@exp_year}, cvv: #{@cvv},"\
  " additional_properties: #{@additional_properties}>"
end