Class: SplititWebApiV4::OffersPaymentMethod

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/splitit_web_api_v4/models/offers_payment_method.rb

Overview

OffersPaymentMethod Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(card_details:, additional_properties: nil) ⇒ OffersPaymentMethod

Returns a new instance of OffersPaymentMethod.



38
39
40
41
42
43
44
45
# File 'lib/splitit_web_api_v4/models/offers_payment_method.rb', line 38

def initialize(card_details:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @type = 'Card'
  @card_details = card_details
  @additional_properties = additional_properties
end

Instance Attribute Details

#card_detailsOffersCardDetails

TODO: Write general description for this method

Returns:



18
19
20
# File 'lib/splitit_web_api_v4/models/offers_payment_method.rb', line 18

def card_details
  @card_details
end

#typeString (readonly)

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/splitit_web_api_v4/models/offers_payment_method.rb', line 14

def type
  @type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
# File 'lib/splitit_web_api_v4/models/offers_payment_method.rb', line 48

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  card_details = OffersCardDetails.from_hash(hash['CardDetails']) if hash['CardDetails']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  OffersPaymentMethod.new(card_details: card_details,
                          additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/splitit_web_api_v4/models/offers_payment_method.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['type'] = 'Type'
  @_hash['card_details'] = 'CardDetails'
  @_hash
end

.nullablesObject

An array for nullable fields



34
35
36
# File 'lib/splitit_web_api_v4/models/offers_payment_method.rb', line 34

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
# File 'lib/splitit_web_api_v4/models/offers_payment_method.rb', line 29

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



74
75
76
77
78
# File 'lib/splitit_web_api_v4/models/offers_payment_method.rb', line 74

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} type: #{@type.inspect}, card_details: #{@card_details.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



67
68
69
70
71
# File 'lib/splitit_web_api_v4/models/offers_payment_method.rb', line 67

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} type: #{@type}, card_details: #{@card_details}, additional_properties:"\
  " #{@additional_properties}>"
end