Class: SplititWebApiV4::OffersShopperDetails

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/splitit_web_api_v4/models/offers_shopper_details.rb

Overview

OffersShopperDetails Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(last_name:, email:, first_name: SKIP, phone_number: SKIP, shopper_locale: SKIP, billing_address: SKIP, additional_properties: nil) ⇒ OffersShopperDetails

Returns a new instance of OffersShopperDetails.



63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/splitit_web_api_v4/models/offers_shopper_details.rb', line 63

def initialize(last_name:, email:, first_name: SKIP, phone_number: SKIP,
               shopper_locale: SKIP, billing_address: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @first_name = first_name unless first_name == SKIP
  @last_name = last_name
  @email = email
  @phone_number = phone_number unless phone_number == SKIP
  @shopper_locale = shopper_locale unless shopper_locale == SKIP
  @billing_address = billing_address unless billing_address == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#billing_addressOffersBillingAddress

TODO: Write general description for this method



34
35
36
# File 'lib/splitit_web_api_v4/models/offers_shopper_details.rb', line 34

def billing_address
  @billing_address
end

#emailString

TODO: Write general description for this method

Returns:

  • (String)


22
23
24
# File 'lib/splitit_web_api_v4/models/offers_shopper_details.rb', line 22

def email
  @email
end

#first_nameString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/splitit_web_api_v4/models/offers_shopper_details.rb', line 14

def first_name
  @first_name
end

#last_nameString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/splitit_web_api_v4/models/offers_shopper_details.rb', line 18

def last_name
  @last_name
end

#phone_numberString

TODO: Write general description for this method

Returns:

  • (String)


26
27
28
# File 'lib/splitit_web_api_v4/models/offers_shopper_details.rb', line 26

def phone_number
  @phone_number
end

#shopper_localeString

TODO: Write general description for this method

Returns:

  • (String)


30
31
32
# File 'lib/splitit_web_api_v4/models/offers_shopper_details.rb', line 30

def shopper_locale
  @shopper_locale
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/splitit_web_api_v4/models/offers_shopper_details.rb', line 79

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  last_name = hash.key?('LastName') ? hash['LastName'] : nil
  email = hash.key?('Email') ? hash['Email'] : nil
  first_name = hash.key?('FirstName') ? hash['FirstName'] : SKIP
  phone_number = hash.key?('PhoneNumber') ? hash['PhoneNumber'] : SKIP
  shopper_locale = hash.key?('ShopperLocale') ? hash['ShopperLocale'] : SKIP
  billing_address = OffersBillingAddress.from_hash(hash['BillingAddress']) if
    hash['BillingAddress']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  OffersShopperDetails.new(last_name: last_name,
                           email: email,
                           first_name: first_name,
                           phone_number: phone_number,
                           shopper_locale: shopper_locale,
                           billing_address: billing_address,
                           additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



37
38
39
40
41
42
43
44
45
46
# File 'lib/splitit_web_api_v4/models/offers_shopper_details.rb', line 37

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['first_name'] = 'FirstName'
  @_hash['last_name'] = 'LastName'
  @_hash['email'] = 'Email'
  @_hash['phone_number'] = 'PhoneNumber'
  @_hash['shopper_locale'] = 'ShopperLocale'
  @_hash['billing_address'] = 'BillingAddress'
  @_hash
end

.nullablesObject

An array for nullable fields



59
60
61
# File 'lib/splitit_web_api_v4/models/offers_shopper_details.rb', line 59

def self.nullables
  []
end

.optionalsObject

An array for optional fields



49
50
51
52
53
54
55
56
# File 'lib/splitit_web_api_v4/models/offers_shopper_details.rb', line 49

def self.optionals
  %w[
    first_name
    phone_number
    shopper_locale
    billing_address
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



117
118
119
120
121
122
123
# File 'lib/splitit_web_api_v4/models/offers_shopper_details.rb', line 117

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} first_name: #{@first_name.inspect}, last_name: #{@last_name.inspect},"\
  " email: #{@email.inspect}, phone_number: #{@phone_number.inspect}, shopper_locale:"\
  " #{@shopper_locale.inspect}, billing_address: #{@billing_address.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



109
110
111
112
113
114
# File 'lib/splitit_web_api_v4/models/offers_shopper_details.rb', line 109

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} first_name: #{@first_name}, last_name: #{@last_name}, email: #{@email},"\
  " phone_number: #{@phone_number}, shopper_locale: #{@shopper_locale}, billing_address:"\
  " #{@billing_address}, additional_properties: #{@additional_properties}>"
end