Class: SplititWebApiV4::PlanLinksData

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/splitit_web_api_v4/models/plan_links_data.rb

Overview

PlanLinksData Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(key: SKIP, label: SKIP, value: SKIP, description: SKIP, additional_properties: nil) ⇒ PlanLinksData

Returns a new instance of PlanLinksData.



53
54
55
56
57
58
59
60
61
62
63
# File 'lib/splitit_web_api_v4/models/plan_links_data.rb', line 53

def initialize(key: SKIP, label: SKIP, value: SKIP, description: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @key = key unless key == SKIP
  @label = label unless label == SKIP
  @value = value unless value == SKIP
  @description = description unless description == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#descriptionString

TODO: Write general description for this method

Returns:

  • (String)


26
27
28
# File 'lib/splitit_web_api_v4/models/plan_links_data.rb', line 26

def description
  @description
end

#keyString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/splitit_web_api_v4/models/plan_links_data.rb', line 14

def key
  @key
end

#labelString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/splitit_web_api_v4/models/plan_links_data.rb', line 18

def label
  @label
end

#valueString

TODO: Write general description for this method

Returns:

  • (String)


22
23
24
# File 'lib/splitit_web_api_v4/models/plan_links_data.rb', line 22

def value
  @value
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/splitit_web_api_v4/models/plan_links_data.rb', line 66

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  key = hash.key?('Key') ? hash['Key'] : SKIP
  label = hash.key?('Label') ? hash['Label'] : SKIP
  value = hash.key?('Value') ? hash['Value'] : SKIP
  description = hash.key?('Description') ? hash['Description'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PlanLinksData.new(key: key,
                    label: label,
                    value: value,
                    description: description,
                    additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



29
30
31
32
33
34
35
36
# File 'lib/splitit_web_api_v4/models/plan_links_data.rb', line 29

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['key'] = 'Key'
  @_hash['label'] = 'Label'
  @_hash['value'] = 'Value'
  @_hash['description'] = 'Description'
  @_hash
end

.nullablesObject

An array for nullable fields



49
50
51
# File 'lib/splitit_web_api_v4/models/plan_links_data.rb', line 49

def self.nullables
  []
end

.optionalsObject

An array for optional fields



39
40
41
42
43
44
45
46
# File 'lib/splitit_web_api_v4/models/plan_links_data.rb', line 39

def self.optionals
  %w[
    key
    label
    value
    description
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



98
99
100
101
102
# File 'lib/splitit_web_api_v4/models/plan_links_data.rb', line 98

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} key: #{@key.inspect}, label: #{@label.inspect}, value: #{@value.inspect},"\
  " description: #{@description.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



91
92
93
94
95
# File 'lib/splitit_web_api_v4/models/plan_links_data.rb', line 91

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} key: #{@key}, label: #{@label}, value: #{@value}, description:"\
  " #{@description}, additional_properties: #{@additional_properties}>"
end