Class: SplititWebApiV4::RedirectUrls
- Defined in:
- lib/splitit_web_api_v4/models/redirect_urls.rb
Overview
RedirectUrls Model.
Instance Attribute Summary collapse
-
#cancel_url ⇒ String
TODO: Write general description for this method.
-
#failure_url ⇒ String
TODO: Write general description for this method.
-
#success_url ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(success_url:, failure_url: SKIP, cancel_url: SKIP, additional_properties: nil) ⇒ RedirectUrls
constructor
A new instance of RedirectUrls.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(success_url:, failure_url: SKIP, cancel_url: SKIP, additional_properties: nil) ⇒ RedirectUrls
Returns a new instance of RedirectUrls.
46 47 48 49 50 51 52 53 54 55 |
# File 'lib/splitit_web_api_v4/models/redirect_urls.rb', line 46 def initialize(success_url:, failure_url: SKIP, cancel_url: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @success_url = success_url @failure_url = failure_url unless failure_url == SKIP @cancel_url = cancel_url unless cancel_url == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#cancel_url ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/splitit_web_api_v4/models/redirect_urls.rb', line 22 def cancel_url @cancel_url end |
#failure_url ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/splitit_web_api_v4/models/redirect_urls.rb', line 18 def failure_url @failure_url end |
#success_url ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/splitit_web_api_v4/models/redirect_urls.rb', line 14 def success_url @success_url end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/splitit_web_api_v4/models/redirect_urls.rb', line 58 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. success_url = hash.key?('SuccessUrl') ? hash['SuccessUrl'] : nil failure_url = hash.key?('FailureUrl') ? hash['FailureUrl'] : SKIP cancel_url = hash.key?('CancelUrl') ? hash['CancelUrl'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. RedirectUrls.new(success_url: success_url, failure_url: failure_url, cancel_url: cancel_url, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/splitit_web_api_v4/models/redirect_urls.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['success_url'] = 'SuccessUrl' @_hash['failure_url'] = 'FailureUrl' @_hash['cancel_url'] = 'CancelUrl' @_hash end |
.nullables ⇒ Object
An array for nullable fields
42 43 44 |
# File 'lib/splitit_web_api_v4/models/redirect_urls.rb', line 42 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 |
# File 'lib/splitit_web_api_v4/models/redirect_urls.rb', line 34 def self.optionals %w[ failure_url cancel_url ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
88 89 90 91 92 |
# File 'lib/splitit_web_api_v4/models/redirect_urls.rb', line 88 def inspect class_name = self.class.name.split('::').last "<#{class_name} success_url: #{@success_url.inspect}, failure_url: #{@failure_url.inspect},"\ " cancel_url: #{@cancel_url.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
81 82 83 84 85 |
# File 'lib/splitit_web_api_v4/models/redirect_urls.rb', line 81 def to_s class_name = self.class.name.split('::').last "<#{class_name} success_url: #{@success_url}, failure_url: #{@failure_url}, cancel_url:"\ " #{@cancel_url}, additional_properties: #{@additional_properties}>" end |