Class: SplititWebApiV4::RefundRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/splitit_web_api_v4/models/refund_request.rb

Overview

RefundRequest Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(amount:, refund_strategy:, reference_id: SKIP, additional_properties: nil) ⇒ RefundRequest

Returns a new instance of RefundRequest.



45
46
47
48
49
50
51
52
53
54
# File 'lib/splitit_web_api_v4/models/refund_request.rb', line 45

def initialize(amount:, refund_strategy:, reference_id: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @amount = amount
  @reference_id = reference_id unless reference_id == SKIP
  @refund_strategy = refund_strategy
  @additional_properties = additional_properties
end

Instance Attribute Details

#amountString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/splitit_web_api_v4/models/refund_request.rb', line 14

def amount
  @amount
end

#reference_idString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/splitit_web_api_v4/models/refund_request.rb', line 18

def reference_id
  @reference_id
end

#refund_strategyRefundStrategy

TODO: Write general description for this method

Returns:



22
23
24
# File 'lib/splitit_web_api_v4/models/refund_request.rb', line 22

def refund_strategy
  @refund_strategy
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/splitit_web_api_v4/models/refund_request.rb', line 57

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  amount = hash.key?('Amount') ? hash['Amount'] : nil
  refund_strategy =
    hash.key?('RefundStrategy') ? hash['RefundStrategy'] : nil
  reference_id = hash.key?('ReferenceId') ? hash['ReferenceId'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  RefundRequest.new(amount: amount,
                    refund_strategy: refund_strategy,
                    reference_id: reference_id,
                    additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/splitit_web_api_v4/models/refund_request.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['amount'] = 'Amount'
  @_hash['reference_id'] = 'ReferenceId'
  @_hash['refund_strategy'] = 'RefundStrategy'
  @_hash
end

.nullablesObject

An array for nullable fields



41
42
43
# File 'lib/splitit_web_api_v4/models/refund_request.rb', line 41

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
# File 'lib/splitit_web_api_v4/models/refund_request.rb', line 34

def self.optionals
  %w[
    reference_id
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



88
89
90
91
92
93
# File 'lib/splitit_web_api_v4/models/refund_request.rb', line 88

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} amount: #{@amount.inspect}, reference_id: #{@reference_id.inspect},"\
  " refund_strategy: #{@refund_strategy.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



81
82
83
84
85
# File 'lib/splitit_web_api_v4/models/refund_request.rb', line 81

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} amount: #{@amount}, reference_id: #{@reference_id}, refund_strategy:"\
  " #{@refund_strategy}, additional_properties: #{@additional_properties}>"
end