Class: SplititWebApiV4::ShopperDetailsData

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/splitit_web_api_v4/models/shopper_details_data.rb

Overview

ShopperDetailsData Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(first_name: SKIP, last_name: SKIP, email: SKIP, phone_number: SKIP, culture: SKIP, billing_address: SKIP, additional_properties: nil) ⇒ ShopperDetailsData

Returns a new instance of ShopperDetailsData.



65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/splitit_web_api_v4/models/shopper_details_data.rb', line 65

def initialize(first_name: SKIP, last_name: SKIP, email: SKIP,
               phone_number: SKIP, culture: SKIP, billing_address: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @first_name = first_name unless first_name == SKIP
  @last_name = last_name unless last_name == SKIP
  @email = email unless email == SKIP
  @phone_number = phone_number unless phone_number == SKIP
  @culture = culture unless culture == SKIP
  @billing_address = billing_address unless billing_address == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#billing_addressBillingAddressData

TODO: Write general description for this method

Returns:



34
35
36
# File 'lib/splitit_web_api_v4/models/shopper_details_data.rb', line 34

def billing_address
  @billing_address
end

#cultureString

TODO: Write general description for this method

Returns:

  • (String)


30
31
32
# File 'lib/splitit_web_api_v4/models/shopper_details_data.rb', line 30

def culture
  @culture
end

#emailString

TODO: Write general description for this method

Returns:

  • (String)


22
23
24
# File 'lib/splitit_web_api_v4/models/shopper_details_data.rb', line 22

def email
  @email
end

#first_nameString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/splitit_web_api_v4/models/shopper_details_data.rb', line 14

def first_name
  @first_name
end

#last_nameString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/splitit_web_api_v4/models/shopper_details_data.rb', line 18

def last_name
  @last_name
end

#phone_numberString

TODO: Write general description for this method

Returns:

  • (String)


26
27
28
# File 'lib/splitit_web_api_v4/models/shopper_details_data.rb', line 26

def phone_number
  @phone_number
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/splitit_web_api_v4/models/shopper_details_data.rb', line 81

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  first_name = hash.key?('FirstName') ? hash['FirstName'] : SKIP
  last_name = hash.key?('LastName') ? hash['LastName'] : SKIP
  email = hash.key?('Email') ? hash['Email'] : SKIP
  phone_number = hash.key?('PhoneNumber') ? hash['PhoneNumber'] : SKIP
  culture = hash.key?('Culture') ? hash['Culture'] : SKIP
  billing_address = BillingAddressData.from_hash(hash['BillingAddress']) if
    hash['BillingAddress']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ShopperDetailsData.new(first_name: first_name,
                         last_name: last_name,
                         email: email,
                         phone_number: phone_number,
                         culture: culture,
                         billing_address: billing_address,
                         additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



37
38
39
40
41
42
43
44
45
46
# File 'lib/splitit_web_api_v4/models/shopper_details_data.rb', line 37

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['first_name'] = 'FirstName'
  @_hash['last_name'] = 'LastName'
  @_hash['email'] = 'Email'
  @_hash['phone_number'] = 'PhoneNumber'
  @_hash['culture'] = 'Culture'
  @_hash['billing_address'] = 'BillingAddress'
  @_hash
end

.nullablesObject

An array for nullable fields



61
62
63
# File 'lib/splitit_web_api_v4/models/shopper_details_data.rb', line 61

def self.nullables
  []
end

.optionalsObject

An array for optional fields



49
50
51
52
53
54
55
56
57
58
# File 'lib/splitit_web_api_v4/models/shopper_details_data.rb', line 49

def self.optionals
  %w[
    first_name
    last_name
    email
    phone_number
    culture
    billing_address
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



119
120
121
122
123
124
125
# File 'lib/splitit_web_api_v4/models/shopper_details_data.rb', line 119

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} first_name: #{@first_name.inspect}, last_name: #{@last_name.inspect},"\
  " email: #{@email.inspect}, phone_number: #{@phone_number.inspect}, culture:"\
  " #{@culture.inspect}, billing_address: #{@billing_address.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



111
112
113
114
115
116
# File 'lib/splitit_web_api_v4/models/shopper_details_data.rb', line 111

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} first_name: #{@first_name}, last_name: #{@last_name}, email: #{@email},"\
  " phone_number: #{@phone_number}, culture: #{@culture}, billing_address:"\
  " #{@billing_address}, additional_properties: #{@additional_properties}>"
end