Class: SplititWebApiV4::ThreeDsExecute

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/splitit_web_api_v4/models/three_ds_execute.rb

Overview

ThreeDsExecute Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(execute: SKIP, additional_properties: nil) ⇒ ThreeDsExecute

Returns a new instance of ThreeDsExecute.



35
36
37
38
39
40
41
# File 'lib/splitit_web_api_v4/models/three_ds_execute.rb', line 35

def initialize(execute: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @execute = execute unless execute == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#executeTrueClass | FalseClass

TODO: Write general description for this method

Returns:

  • (TrueClass | FalseClass)


14
15
16
# File 'lib/splitit_web_api_v4/models/three_ds_execute.rb', line 14

def execute
  @execute
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
# File 'lib/splitit_web_api_v4/models/three_ds_execute.rb', line 44

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  execute = hash.key?('Execute') ? hash['Execute'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ThreeDsExecute.new(execute: execute,
                     additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



17
18
19
20
21
# File 'lib/splitit_web_api_v4/models/three_ds_execute.rb', line 17

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['execute'] = 'Execute'
  @_hash
end

.nullablesObject

An array for nullable fields



31
32
33
# File 'lib/splitit_web_api_v4/models/three_ds_execute.rb', line 31

def self.nullables
  []
end

.optionalsObject

An array for optional fields



24
25
26
27
28
# File 'lib/splitit_web_api_v4/models/three_ds_execute.rb', line 24

def self.optionals
  %w[
    execute
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



69
70
71
72
73
# File 'lib/splitit_web_api_v4/models/three_ds_execute.rb', line 69

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} execute: #{@execute.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



63
64
65
66
# File 'lib/splitit_web_api_v4/models/three_ds_execute.rb', line 63

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} execute: #{@execute}, additional_properties: #{@additional_properties}>"
end