Class: SplititWebApiV4::ThreeDsRedirectData

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/splitit_web_api_v4/models/three_ds_redirect_data.rb

Overview

ThreeDsRedirectData Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(url: SKIP, verb: SKIP, params: SKIP, client_redirect_url: SKIP, additional_properties: nil) ⇒ ThreeDsRedirectData

Returns a new instance of ThreeDsRedirectData.



53
54
55
56
57
58
59
60
61
62
63
# File 'lib/splitit_web_api_v4/models/three_ds_redirect_data.rb', line 53

def initialize(url: SKIP, verb: SKIP, params: SKIP,
               client_redirect_url: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @url = url unless url == SKIP
  @verb = verb unless verb == SKIP
  @params = params unless params == SKIP
  @client_redirect_url = client_redirect_url unless client_redirect_url == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#client_redirect_urlString

TODO: Write general description for this method

Returns:

  • (String)


26
27
28
# File 'lib/splitit_web_api_v4/models/three_ds_redirect_data.rb', line 26

def client_redirect_url
  @client_redirect_url
end

#paramsHash[String, String]

TODO: Write general description for this method

Returns:

  • (Hash[String, String])


22
23
24
# File 'lib/splitit_web_api_v4/models/three_ds_redirect_data.rb', line 22

def params
  @params
end

#urlString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/splitit_web_api_v4/models/three_ds_redirect_data.rb', line 14

def url
  @url
end

#verbString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/splitit_web_api_v4/models/three_ds_redirect_data.rb', line 18

def verb
  @verb
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/splitit_web_api_v4/models/three_ds_redirect_data.rb', line 66

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  url = hash.key?('Url') ? hash['Url'] : SKIP
  verb = hash.key?('Verb') ? hash['Verb'] : SKIP
  params = hash.key?('Params') ? hash['Params'] : SKIP
  client_redirect_url =
    hash.key?('ClientRedirectUrl') ? hash['ClientRedirectUrl'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ThreeDsRedirectData.new(url: url,
                          verb: verb,
                          params: params,
                          client_redirect_url: client_redirect_url,
                          additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



29
30
31
32
33
34
35
36
# File 'lib/splitit_web_api_v4/models/three_ds_redirect_data.rb', line 29

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['url'] = 'Url'
  @_hash['verb'] = 'Verb'
  @_hash['params'] = 'Params'
  @_hash['client_redirect_url'] = 'ClientRedirectUrl'
  @_hash
end

.nullablesObject

An array for nullable fields



49
50
51
# File 'lib/splitit_web_api_v4/models/three_ds_redirect_data.rb', line 49

def self.nullables
  []
end

.optionalsObject

An array for optional fields



39
40
41
42
43
44
45
46
# File 'lib/splitit_web_api_v4/models/three_ds_redirect_data.rb', line 39

def self.optionals
  %w[
    url
    verb
    params
    client_redirect_url
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



99
100
101
102
103
104
# File 'lib/splitit_web_api_v4/models/three_ds_redirect_data.rb', line 99

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} url: #{@url.inspect}, verb: #{@verb.inspect}, params: #{@params.inspect},"\
  " client_redirect_url: #{@client_redirect_url.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



92
93
94
95
96
# File 'lib/splitit_web_api_v4/models/three_ds_redirect_data.rb', line 92

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} url: #{@url}, verb: #{@verb}, params: #{@params}, client_redirect_url:"\
  " #{@client_redirect_url}, additional_properties: #{@additional_properties}>"
end