Class: SplititWebApiV4::ThreeDsRequestData

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/splitit_web_api_v4/models/three_ds_request_data.rb

Overview

ThreeDsRequestData Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(execute: SKIP, three_dsur_ls: SKIP, authentication_data: SKIP, additional_properties: nil) ⇒ ThreeDsRequestData

Returns a new instance of ThreeDsRequestData.



47
48
49
50
51
52
53
54
55
56
# File 'lib/splitit_web_api_v4/models/three_ds_request_data.rb', line 47

def initialize(execute: SKIP, three_dsur_ls: SKIP,
               authentication_data: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @execute = execute unless execute == SKIP
  @three_dsur_ls = three_dsur_ls unless three_dsur_ls == SKIP
  @authentication_data = authentication_data unless authentication_data == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#authentication_dataThreeDsAuthenticationData

TODO: Write general description for this method



22
23
24
# File 'lib/splitit_web_api_v4/models/three_ds_request_data.rb', line 22

def authentication_data
  @authentication_data
end

#executeTrueClass | FalseClass

TODO: Write general description for this method

Returns:

  • (TrueClass | FalseClass)


14
15
16
# File 'lib/splitit_web_api_v4/models/three_ds_request_data.rb', line 14

def execute
  @execute
end

#three_dsur_lsRedirectUrls

TODO: Write general description for this method

Returns:



18
19
20
# File 'lib/splitit_web_api_v4/models/three_ds_request_data.rb', line 18

def three_dsur_ls
  @three_dsur_ls
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/splitit_web_api_v4/models/three_ds_request_data.rb', line 59

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  execute = hash.key?('Execute') ? hash['Execute'] : SKIP
  three_dsur_ls = RedirectUrls.from_hash(hash['ThreeDSURLs']) if hash['ThreeDSURLs']
  authentication_data = ThreeDsAuthenticationData.from_hash(hash['AuthenticationData']) if
    hash['AuthenticationData']

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ThreeDsRequestData.new(execute: execute,
                         three_dsur_ls: three_dsur_ls,
                         authentication_data: authentication_data,
                         additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/splitit_web_api_v4/models/three_ds_request_data.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['execute'] = 'Execute'
  @_hash['three_dsur_ls'] = 'ThreeDSURLs'
  @_hash['authentication_data'] = 'AuthenticationData'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/splitit_web_api_v4/models/three_ds_request_data.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/splitit_web_api_v4/models/three_ds_request_data.rb', line 34

def self.optionals
  %w[
    execute
    three_dsur_ls
    authentication_data
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



91
92
93
94
95
96
# File 'lib/splitit_web_api_v4/models/three_ds_request_data.rb', line 91

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} execute: #{@execute.inspect}, three_dsur_ls: #{@three_dsur_ls.inspect},"\
  " authentication_data: #{@authentication_data.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



83
84
85
86
87
88
# File 'lib/splitit_web_api_v4/models/three_ds_request_data.rb', line 83

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} execute: #{@execute}, three_dsur_ls: #{@three_dsur_ls},"\
  " authentication_data: #{@authentication_data}, additional_properties:"\
  " #{@additional_properties}>"
end