Class: SplititWebApiV4::ValidationError

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/splitit_web_api_v4/models/validation_error.rb

Overview

ValidationError Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(code: SKIP, message: SKIP, additional_properties: nil) ⇒ ValidationError

Returns a new instance of ValidationError.



41
42
43
44
45
46
47
48
# File 'lib/splitit_web_api_v4/models/validation_error.rb', line 41

def initialize(code: SKIP, message: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @code = code unless code == SKIP
  @message = message unless message == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#codePisErrorCodes

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/splitit_web_api_v4/models/validation_error.rb', line 14

def code
  @code
end

#messageString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/splitit_web_api_v4/models/validation_error.rb', line 18

def message
  @message
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/splitit_web_api_v4/models/validation_error.rb', line 51

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  code = hash.key?('Code') ? hash['Code'] : SKIP
  message = hash.key?('Message') ? hash['Message'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ValidationError.new(code: code,
                      message: message,
                      additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/splitit_web_api_v4/models/validation_error.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['code'] = 'Code'
  @_hash['message'] = 'Message'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/splitit_web_api_v4/models/validation_error.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/splitit_web_api_v4/models/validation_error.rb', line 29

def self.optionals
  %w[
    code
    message
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



79
80
81
82
83
# File 'lib/splitit_web_api_v4/models/validation_error.rb', line 79

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} code: #{@code.inspect}, message: #{@message.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



72
73
74
75
76
# File 'lib/splitit_web_api_v4/models/validation_error.rb', line 72

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} code: #{@code}, message: #{@message}, additional_properties:"\
  " #{@additional_properties}>"
end