Class: SplititWebApiV4::AmountData
- Defined in:
- lib/splitit_web_api_v4/models/amount_data.rb
Overview
AmountData Model.
Instance Attribute Summary collapse
-
#symbol ⇒ String
TODO: Write general description for this method.
-
#value ⇒ Float
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(value:, symbol: SKIP, additional_properties: nil) ⇒ AmountData
constructor
A new instance of AmountData.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(value:, symbol: SKIP, additional_properties: nil) ⇒ AmountData
Returns a new instance of AmountData.
40 41 42 43 44 45 46 47 |
# File 'lib/splitit_web_api_v4/models/amount_data.rb', line 40 def initialize(value:, symbol: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @value = value @symbol = symbol unless symbol == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#symbol ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/splitit_web_api_v4/models/amount_data.rb', line 18 def symbol @symbol end |
#value ⇒ Float
TODO: Write general description for this method
14 15 16 |
# File 'lib/splitit_web_api_v4/models/amount_data.rb', line 14 def value @value end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/splitit_web_api_v4/models/amount_data.rb', line 50 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. value = hash.key?('Value') ? hash['Value'] : nil symbol = hash.key?('Symbol') ? hash['Symbol'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. AmountData.new(value: value, symbol: symbol, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/splitit_web_api_v4/models/amount_data.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['value'] = 'Value' @_hash['symbol'] = 'Symbol' @_hash end |
.nullables ⇒ Object
An array for nullable fields
36 37 38 |
# File 'lib/splitit_web_api_v4/models/amount_data.rb', line 36 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 |
# File 'lib/splitit_web_api_v4/models/amount_data.rb', line 29 def self.optionals %w[ symbol ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
78 79 80 81 82 |
# File 'lib/splitit_web_api_v4/models/amount_data.rb', line 78 def inspect class_name = self.class.name.split('::').last "<#{class_name} value: #{@value.inspect}, symbol: #{@symbol.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
71 72 73 74 75 |
# File 'lib/splitit_web_api_v4/models/amount_data.rb', line 71 def to_s class_name = self.class.name.split('::').last "<#{class_name} value: #{@value}, symbol: #{@symbol}, additional_properties:"\ " #{@additional_properties}>" end |