Class: SplititWebApiV4::BillingAddressData
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- SplititWebApiV4::BillingAddressData
- Defined in:
- lib/splitit_web_api_v4/models/billing_address_data.rb
Overview
BillingAddressData Model.
Instance Attribute Summary collapse
-
#city ⇒ String
TODO: Write general description for this method.
-
#country ⇒ String
TODO: Write general description for this method.
-
#line1 ⇒ String
TODO: Write general description for this method.
-
#line2 ⇒ String
TODO: Write general description for this method.
-
#postal_code ⇒ String
TODO: Write general description for this method.
-
#state ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(line1: SKIP, line2: SKIP, city: SKIP, state: SKIP, postal_code: SKIP, country: SKIP, additional_properties: nil) ⇒ BillingAddressData
constructor
A new instance of BillingAddressData.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(line1: SKIP, line2: SKIP, city: SKIP, state: SKIP, postal_code: SKIP, country: SKIP, additional_properties: nil) ⇒ BillingAddressData
Returns a new instance of BillingAddressData.
65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/splitit_web_api_v4/models/billing_address_data.rb', line 65 def initialize(line1: SKIP, line2: SKIP, city: SKIP, state: SKIP, postal_code: SKIP, country: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @line1 = line1 unless line1 == SKIP @line2 = line2 unless line2 == SKIP @city = city unless city == SKIP @state = state unless state == SKIP @postal_code = postal_code unless postal_code == SKIP @country = country unless country == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#city ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/splitit_web_api_v4/models/billing_address_data.rb', line 22 def city @city end |
#country ⇒ String
TODO: Write general description for this method
34 35 36 |
# File 'lib/splitit_web_api_v4/models/billing_address_data.rb', line 34 def country @country end |
#line1 ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/splitit_web_api_v4/models/billing_address_data.rb', line 14 def line1 @line1 end |
#line2 ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/splitit_web_api_v4/models/billing_address_data.rb', line 18 def line2 @line2 end |
#postal_code ⇒ String
TODO: Write general description for this method
30 31 32 |
# File 'lib/splitit_web_api_v4/models/billing_address_data.rb', line 30 def postal_code @postal_code end |
#state ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/splitit_web_api_v4/models/billing_address_data.rb', line 26 def state @state end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/splitit_web_api_v4/models/billing_address_data.rb', line 80 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. line1 = hash.key?('Line1') ? hash['Line1'] : SKIP line2 = hash.key?('Line2') ? hash['Line2'] : SKIP city = hash.key?('City') ? hash['City'] : SKIP state = hash.key?('State') ? hash['State'] : SKIP postal_code = hash.key?('PostalCode') ? hash['PostalCode'] : SKIP country = hash.key?('Country') ? hash['Country'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. BillingAddressData.new(line1: line1, line2: line2, city: city, state: state, postal_code: postal_code, country: country, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
37 38 39 40 41 42 43 44 45 46 |
# File 'lib/splitit_web_api_v4/models/billing_address_data.rb', line 37 def self.names @_hash = {} if @_hash.nil? @_hash['line1'] = 'Line1' @_hash['line2'] = 'Line2' @_hash['city'] = 'City' @_hash['state'] = 'State' @_hash['postal_code'] = 'PostalCode' @_hash['country'] = 'Country' @_hash end |
.nullables ⇒ Object
An array for nullable fields
61 62 63 |
# File 'lib/splitit_web_api_v4/models/billing_address_data.rb', line 61 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
49 50 51 52 53 54 55 56 57 58 |
# File 'lib/splitit_web_api_v4/models/billing_address_data.rb', line 49 def self.optionals %w[ line1 line2 city state postal_code country ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
117 118 119 120 121 122 |
# File 'lib/splitit_web_api_v4/models/billing_address_data.rb', line 117 def inspect class_name = self.class.name.split('::').last "<#{class_name} line1: #{@line1.inspect}, line2: #{@line2.inspect}, city: #{@city.inspect},"\ " state: #{@state.inspect}, postal_code: #{@postal_code.inspect}, country:"\ " #{@country.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
109 110 111 112 113 114 |
# File 'lib/splitit_web_api_v4/models/billing_address_data.rb', line 109 def to_s class_name = self.class.name.split('::').last "<#{class_name} line1: #{@line1}, line2: #{@line2}, city: #{@city}, state: #{@state},"\ " postal_code: #{@postal_code}, country: #{@country}, additional_properties:"\ " #{@additional_properties}>" end |