Class: SplititWebApiV4::OffersMerchantDetails
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- SplititWebApiV4::OffersMerchantDetails
- Defined in:
- lib/splitit_web_api_v4/models/offers_merchant_details.rb
Overview
OffersMerchantDetails Model.
Instance Attribute Summary collapse
-
#store_id ⇒ String
TODO: Write general description for this method.
-
#store_location ⇒ OffersStoreLocation
TODO: Write general description for this method.
-
#store_name ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(store_location:, store_name: SKIP, store_id: SKIP, additional_properties: nil) ⇒ OffersMerchantDetails
constructor
A new instance of OffersMerchantDetails.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(store_location:, store_name: SKIP, store_id: SKIP, additional_properties: nil) ⇒ OffersMerchantDetails
Returns a new instance of OffersMerchantDetails.
46 47 48 49 50 51 52 53 54 55 |
# File 'lib/splitit_web_api_v4/models/offers_merchant_details.rb', line 46 def initialize(store_location:, store_name: SKIP, store_id: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @store_name = store_name unless store_name == SKIP @store_id = store_id unless store_id == SKIP @store_location = store_location @additional_properties = additional_properties end |
Instance Attribute Details
#store_id ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/splitit_web_api_v4/models/offers_merchant_details.rb', line 18 def store_id @store_id end |
#store_location ⇒ OffersStoreLocation
TODO: Write general description for this method
22 23 24 |
# File 'lib/splitit_web_api_v4/models/offers_merchant_details.rb', line 22 def store_location @store_location end |
#store_name ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/splitit_web_api_v4/models/offers_merchant_details.rb', line 14 def store_name @store_name end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/splitit_web_api_v4/models/offers_merchant_details.rb', line 58 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. store_location = OffersStoreLocation.from_hash(hash['StoreLocation']) if hash['StoreLocation'] store_name = hash.key?('StoreName') ? hash['StoreName'] : SKIP store_id = hash.key?('StoreId') ? hash['StoreId'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. OffersMerchantDetails.new(store_location: store_location, store_name: store_name, store_id: store_id, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/splitit_web_api_v4/models/offers_merchant_details.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['store_name'] = 'StoreName' @_hash['store_id'] = 'StoreId' @_hash['store_location'] = 'StoreLocation' @_hash end |
.nullables ⇒ Object
An array for nullable fields
42 43 44 |
# File 'lib/splitit_web_api_v4/models/offers_merchant_details.rb', line 42 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 |
# File 'lib/splitit_web_api_v4/models/offers_merchant_details.rb', line 34 def self.optionals %w[ store_name store_id ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
89 90 91 92 93 94 |
# File 'lib/splitit_web_api_v4/models/offers_merchant_details.rb', line 89 def inspect class_name = self.class.name.split('::').last "<#{class_name} store_name: #{@store_name.inspect}, store_id: #{@store_id.inspect},"\ " store_location: #{@store_location.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
82 83 84 85 86 |
# File 'lib/splitit_web_api_v4/models/offers_merchant_details.rb', line 82 def to_s class_name = self.class.name.split('::').last "<#{class_name} store_name: #{@store_name}, store_id: #{@store_id}, store_location:"\ " #{@store_location}, additional_properties: #{@additional_properties}>" end |