Class: SplititWebApiV4::OffersPaymentMethodResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- SplititWebApiV4::OffersPaymentMethodResponse
- Defined in:
- lib/splitit_web_api_v4/models/offers_payment_method_response.rb
Overview
OffersPaymentMethodResponse Model.
Instance Attribute Summary collapse
-
#bin ⇒ String
TODO: Write general description for this method.
-
#issuer_name ⇒ String
TODO: Write general description for this method.
-
#last4_digits ⇒ String
TODO: Write general description for this method.
-
#type ⇒ String
readonly
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(last4_digits: SKIP, bin: SKIP, issuer_name: SKIP, additional_properties: nil) ⇒ OffersPaymentMethodResponse
constructor
A new instance of OffersPaymentMethodResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(last4_digits: SKIP, bin: SKIP, issuer_name: SKIP, additional_properties: nil) ⇒ OffersPaymentMethodResponse
Returns a new instance of OffersPaymentMethodResponse.
52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/splitit_web_api_v4/models/offers_payment_method_response.rb', line 52 def initialize(last4_digits: SKIP, bin: SKIP, issuer_name: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @last4_digits = last4_digits unless last4_digits == SKIP @bin = bin unless bin == SKIP @issuer_name = issuer_name unless issuer_name == SKIP @type = 'Card' @additional_properties = additional_properties end |
Instance Attribute Details
#bin ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/splitit_web_api_v4/models/offers_payment_method_response.rb', line 18 def bin @bin end |
#issuer_name ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/splitit_web_api_v4/models/offers_payment_method_response.rb', line 22 def issuer_name @issuer_name end |
#last4_digits ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/splitit_web_api_v4/models/offers_payment_method_response.rb', line 14 def last4_digits @last4_digits end |
#type ⇒ String (readonly)
TODO: Write general description for this method
26 27 28 |
# File 'lib/splitit_web_api_v4/models/offers_payment_method_response.rb', line 26 def type @type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/splitit_web_api_v4/models/offers_payment_method_response.rb', line 65 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. last4_digits = hash.key?('Last4Digits') ? hash['Last4Digits'] : SKIP bin = hash.key?('BIN') ? hash['BIN'] : SKIP issuer_name = hash.key?('IssuerName') ? hash['IssuerName'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. OffersPaymentMethodResponse.new(last4_digits: last4_digits, bin: bin, issuer_name: issuer_name, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/splitit_web_api_v4/models/offers_payment_method_response.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['last4_digits'] = 'Last4Digits' @_hash['bin'] = 'BIN' @_hash['issuer_name'] = 'IssuerName' @_hash['type'] = 'Type' @_hash end |
.nullables ⇒ Object
An array for nullable fields
48 49 50 |
# File 'lib/splitit_web_api_v4/models/offers_payment_method_response.rb', line 48 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 42 43 44 45 |
# File 'lib/splitit_web_api_v4/models/offers_payment_method_response.rb', line 39 def self.optionals %w[ last4_digits bin issuer_name ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
95 96 97 98 99 100 |
# File 'lib/splitit_web_api_v4/models/offers_payment_method_response.rb', line 95 def inspect class_name = self.class.name.split('::').last "<#{class_name} last4_digits: #{@last4_digits.inspect}, bin: #{@bin.inspect}, issuer_name:"\ " #{@issuer_name.inspect}, type: #{@type.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
88 89 90 91 92 |
# File 'lib/splitit_web_api_v4/models/offers_payment_method_response.rb', line 88 def to_s class_name = self.class.name.split('::').last "<#{class_name} last4_digits: #{@last4_digits}, bin: #{@bin}, issuer_name: #{@issuer_name},"\ " type: #{@type}, additional_properties: #{@additional_properties}>" end |