Class: SplititWebApiV4::ThreeDsAuthenticationData
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- SplititWebApiV4::ThreeDsAuthenticationData
- Defined in:
- lib/splitit_web_api_v4/models/three_ds_authentication_data.rb
Overview
ThreeDsAuthenticationData Model.
Instance Attribute Summary collapse
-
#cavv ⇒ String
TODO: Write general description for this method.
-
#directory_server_transaction_id ⇒ String
TODO: Write general description for this method.
-
#eci ⇒ String
TODO: Write general description for this method.
-
#version ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(eci:, cavv:, directory_server_transaction_id:, version:, additional_properties: nil) ⇒ ThreeDsAuthenticationData
constructor
A new instance of ThreeDsAuthenticationData.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(eci:, cavv:, directory_server_transaction_id:, version:, additional_properties: nil) ⇒ ThreeDsAuthenticationData
Returns a new instance of ThreeDsAuthenticationData.
49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/splitit_web_api_v4/models/three_ds_authentication_data.rb', line 49 def initialize(eci:, cavv:, directory_server_transaction_id:, version:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @eci = eci @cavv = cavv @directory_server_transaction_id = directory_server_transaction_id @version = version @additional_properties = additional_properties end |
Instance Attribute Details
#cavv ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/splitit_web_api_v4/models/three_ds_authentication_data.rb', line 18 def cavv @cavv end |
#directory_server_transaction_id ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/splitit_web_api_v4/models/three_ds_authentication_data.rb', line 22 def directory_server_transaction_id @directory_server_transaction_id end |
#eci ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/splitit_web_api_v4/models/three_ds_authentication_data.rb', line 14 def eci @eci end |
#version ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/splitit_web_api_v4/models/three_ds_authentication_data.rb', line 26 def version @version end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/splitit_web_api_v4/models/three_ds_authentication_data.rb', line 62 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. eci = hash.key?('ECI') ? hash['ECI'] : nil cavv = hash.key?('CAVV') ? hash['CAVV'] : nil directory_server_transaction_id = hash.key?('DirectoryServerTransactionId') ? hash['DirectoryServerTransactionId'] : nil version = hash.key?('Version') ? hash['Version'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ThreeDsAuthenticationData.new(eci: eci, cavv: cavv, directory_server_transaction_id: directory_server_transaction_id, version: version, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 37 |
# File 'lib/splitit_web_api_v4/models/three_ds_authentication_data.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['eci'] = 'ECI' @_hash['cavv'] = 'CAVV' @_hash['directory_server_transaction_id'] = 'DirectoryServerTransactionId' @_hash['version'] = 'Version' @_hash end |
.nullables ⇒ Object
An array for nullable fields
45 46 47 |
# File 'lib/splitit_web_api_v4/models/three_ds_authentication_data.rb', line 45 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
40 41 42 |
# File 'lib/splitit_web_api_v4/models/three_ds_authentication_data.rb', line 40 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
96 97 98 99 100 101 |
# File 'lib/splitit_web_api_v4/models/three_ds_authentication_data.rb', line 96 def inspect class_name = self.class.name.split('::').last "<#{class_name} eci: #{@eci.inspect}, cavv: #{@cavv.inspect},"\ " directory_server_transaction_id: #{@directory_server_transaction_id.inspect}, version:"\ " #{@version.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
88 89 90 91 92 93 |
# File 'lib/splitit_web_api_v4/models/three_ds_authentication_data.rb', line 88 def to_s class_name = self.class.name.split('::').last "<#{class_name} eci: #{@eci}, cavv: #{@cavv}, directory_server_transaction_id:"\ " #{@directory_server_transaction_id}, version: #{@version}, additional_properties:"\ " #{@additional_properties}>" end |